@@ -23,7 +23,7 @@ set.seed(8787)
 n <- 1000
 x1 <- factor(sample(c(0, 1), n, replace = T), ordered=TRUE)
 y  <- sample(c(1, 2, 3, 4), n, replace = T)
-w <- try(orm(Y ~ x1), silent=TRUE)
+w <- try(orm(y ~ x1), silent=TRUE)
 w
 x1 <- factor(sample(c(0, 1), n, replace = T))
-orm(Y ~ x1)
+orm(y ~ x1)
